==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiGui/QSyntaxHighlighter_shell.h <==
#ifndef QSYNTAXHIGHLIGHTER_SHELL_H
#define QSYNTAXHIGHLIGHTER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtGui/qsyntaxhighlighter.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextobject.h>
#include <QtJambi/RegistryAPI>


class QSyntaxHighlighter_shell : public QSyntaxHighlighter, public QtJambiShellInterface
{
public:
    QSyntaxHighlighter_shell(QObject* parent0);
    QSyntaxHighlighter_shell(QTextDocument* parent0);
    ~QSyntaxHighlighter_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void highlightBlock(const QString& text0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSyntaxHighlighter_access : public QSyntaxHighlighter
{
    jobject __qt_currentBlock(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_currentBlockState(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_currentBlockUserData(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_format_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0) const;
    jint __qt_previousBlockState(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setCurrentBlockState_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint newState0);
    void __qt_setCurrentBlockUserData_QTextBlockUserData_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID data0);
    void __qt_setFormat_int_int_cref_QColor(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint start0, jint count1, QtJambiNativeID color2);
    void __qt_setFormat_int_int_cref_QFont(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint start0, jint count1, QtJambiNativeID font2);
    void __qt_setFormat_int_int_cref_QTextCharFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint start0, jint count1, QtJambiNativeID format2);
    void __qt_highlightBlock_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring text0);
};

#endif // QSYNTAXHIGHLIGHTER_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiGui/QSyntaxHighlighter_shell.h <==
#ifndef QSYNTAXHIGHLIGHTER_SHELL_H
#define QSYNTAXHIGHLIGHTER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qsyntaxhighlighter.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextobject.h>
#include <QtJambi/RegistryAPI>


class QSyntaxHighlighter_shell : public QSyntaxHighlighter, public QtJambiShellInterface
{
public:
    QSyntaxHighlighter_shell(QObject* parent0);
    QSyntaxHighlighter_shell(QTextDocument* parent0);
    ~QSyntaxHighlighter_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QSyntaxHighlighter_mshell;
    friend class QSyntaxHighlighter_oshell;
};


class QSyntaxHighlighter_mshell : public QSyntaxHighlighter_shell
{
public:
    using QSyntaxHighlighter_shell::QSyntaxHighlighter_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QSyntaxHighlighter_oshell : public QSyntaxHighlighter_mshell
{
public:
    using QSyntaxHighlighter_mshell::QSyntaxHighlighter_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void highlightBlock(const QString& text0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSyntaxHighlighter_access : public QSyntaxHighlighter
{
    jobject __qt_currentBlock_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_currentBlockState_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_currentBlockUserData_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_format_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0) const;
    jint __qt_previousBlockState_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setCurrentBlockState_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint newState0);
    void __qt_setCurrentBlockUserData_QTextBlockUserData_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID data0);
    void __qt_setFormat_int_int_cref_QColor(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint start0, jint count1, QtJambiNativeID color2);
    void __qt_setFormat_int_int_cref_QFont(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint start0, jint count1, QtJambiNativeID font2);
    void __qt_setFormat_int_int_cref_QTextCharFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint start0, jint count1, QtJambiNativeID format2);
    void __qt_highlightBlock_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring text0);
};

#endif // QSYNTAXHIGHLIGHTER_SHELL_H
